@@ -1,3 +1,12 @@
+"""
+Command-line user interface.
+
+This is the main module of check-python-versions, responsible for handling
+command-line arguments, extracting information about supported Python versions
+from various sources, presenting it to the user and possibly making
+modifications.
+"""
+
 import argparse
 import os
 import sys
@@ -5,28 +14,28 @@ from io import StringIO
 from typing import Callable, Collection, Dict, List, Optional, Tuple
 
 from . import __version__
-from .parsers.appveyor import (
+from .sources.appveyor import (
     APPVEYOR_YML,
     get_appveyor_yml_python_versions,
     update_appveyor_yml_python_versions,
 )
-from .parsers.manylinux import (
+from .sources.manylinux import (
     MANYLINUX_INSTALL_SH,
     get_manylinux_python_versions,
     update_manylinux_python_versions,
 )
-from .parsers.python import (
+from .sources.setup_py import (
     get_python_requires,
     get_supported_python_versions,
     update_python_requires,
     update_supported_python_versions,
 )
-from .parsers.tox import (
+from .sources.tox import (
     TOX_INI,
     get_tox_ini_python_versions,
     update_tox_ini_python_versions,
 )
-from .parsers.travis import (
+from .sources.travis import (
     TRAVIS_YML,
     get_travis_yml_python_versions,
     update_travis_yml_python_versions,
@@ -40,21 +49,13 @@ from .utils import (
 from .versions import (
     MAX_MINOR_FOR_MAJOR,
     SortedVersionList,
+    Version,
     VersionList,
     important,
     update_version_list,
 )
 
 
-try:
-    import yaml  # noqa: F401
-except ImportError:  # pragma: nocover
-    # Shouldn't happen, we install_requires=['PyYAML'], but maybe someone is
-    # running ./check-python-versions directly from a git checkout.
-    print("PyYAML is needed for Travis CI/Appveyor support"
-          " (apt install python3-yaml)")
-
-
 def parse_version(v: str) -> Tuple[int, int]:
     """Parse a Python version number.
 
@@ -113,7 +114,7 @@ def parse_version_list(v: str) -> SortedVersionList:
                 f'bad range: {part} ({lo_major} != {hi_major})')
 
         for vmin in range(lo_minor, hi_minor + 1):
-            versions.add(f'{lo_major}.{vmin}')
+            versions.add(Version(major=lo_major, minor=vmin))
 
     return sorted(versions)
 
@@ -241,13 +242,14 @@ def check_versions(
         versions = extractor(filename_or_replacement(pathname, replacements))
         if versions is None:
             continue
-        print(f"{title} says:".ljust(width), ", ".join(versions) or "(empty)")
+        print(f"{title} says:".ljust(width),
+              ", ".join(str(v) for v in versions) or "(empty)")
         version_sets.append(important(versions))
 
     if not expect:
         expect = version_sets[0]
     else:
-        print("expected:".ljust(width), ', '.join(expect))
+        print("expected:".ljust(width), ', '.join(str(v) for v in expect))
 
     expect = important(expect)
     return all(
@@ -324,10 +326,12 @@ def update_versions(
             fp = filename_or_replacement(pathname, replacements)
             new_lines = updater(fp, new_versions)
             if new_lines is not None:
-                # TODO: refactor this into two functions, one that produces a
-                # replacement dict and does no user interaction, and another
-                # that does user interaction based on the contents of the
-                # replacement dict.
+                # TODO: refactor update_versions() into two functions, one that
+                # produces a replacement dict and does no user interaction, and
+                # another that does user interaction based on the contents of
+                # the replacement dict.  This is because showing a diff for
+                # setup.py twice (once to update classifiers and once to update
+                # python_requires) is weird?
                 if diff:
                     fp = filename_or_replacement(pathname, replacements)
                     show_diff(fp, new_lines)
@@ -342,6 +346,11 @@ def update_versions(
 
 
 def _main() -> None:
+    """The guts of the main() function.
+
+    Parses command-line arguments, does work, reports results, exits with an
+    error code if necessary.
+    """
     parser = argparse.ArgumentParser(
         description="verify that supported Python versions are the same"
                     " in setup.py, tox.ini, .travis.yml and appveyor.yml")
@@ -437,6 +446,12 @@ def _main() -> None:
 
 
 def main() -> None:
+    """The main function.
+
+    It is here because I detest programs that print tracebacks when they're
+    terminated with a Ctrl+C.  I could inline _main() here, but I didn't want
+    to indent all of that code.  Maybe I should've added a decorator instead.
+    """
     try:
         _main()
     except KeyboardInterrupt:
