@@ -1,5 +1,6 @@
 import textwrap
 from io import StringIO
+from typing import List
 
 import pytest
 
@@ -11,15 +12,20 @@ from check_python_versions.sources.tox import (
     update_tox_envlist,
     update_tox_ini_python_versions,
 )
+from check_python_versions.versions import Version
+
+
+def v(versions: List[str]) -> List[Version]:
+    return [Version.from_string(v) for v in versions]
 
 
 def test_get_tox_ini_python_versions(tmp_path):
     tox_ini = tmp_path / "tox.ini"
     tox_ini.write_text(textwrap.dedent("""\
         [tox]
-        envlist = py27,py36,py27-docs,pylint
+        envlist = py27,py36,py27-docs,pylint,py310
     """))
-    assert get_tox_ini_python_versions(tox_ini) == ['2.7', '3.6']
+    assert get_tox_ini_python_versions(tox_ini) == v(['2.7', '3.6', '3.10'])
 
 
 def test_get_tox_ini_python_versions_syntax_error(tmp_path):
@@ -84,6 +90,7 @@ def test_brace_expand(s, expected):
     ('flake8', None),
 ])
 def test_tox_env_to_py_version(s, expected):
+    expected = expected and Version.from_string(expected)
     assert tox_env_to_py_version(s) == expected
 
 
@@ -93,10 +100,10 @@ def test_update_tox_ini_python_versions():
         envlist = py26, py27
     """))
     fp.name = 'tox.ini'
-    result = update_tox_ini_python_versions(fp, ['3.6', '3.7'])
+    result = update_tox_ini_python_versions(fp, v(['3.6', '3.7', '3.10']))
     assert "".join(result) == textwrap.dedent("""\
         [tox]
-        envlist = py36, py37
+        envlist = py36, py37, py310
     """)
 
 
@@ -106,7 +113,7 @@ def test_update_tox_ini_python_syntax_error(capsys):
         envlist = py26, py27
     """))
     fp.name = 'tox.ini'
-    result = update_tox_ini_python_versions(fp, ['3.6', '3.7'])
+    result = update_tox_ini_python_versions(fp, v(['3.6', '3.7']))
     assert "".join(result) == textwrap.dedent("""\
         [tox
         envlist = py26, py27
@@ -118,7 +125,7 @@ def test_update_tox_ini_python_syntax_error(capsys):
 
 
 def test_update_tox_envlist():
-    result = update_tox_envlist('py26,py27,pypy3,flake8', ['3.6', '3.7'])
+    result = update_tox_envlist('py26,py27,pypy3,flake8', v(['3.6', '3.7']))
     assert result == 'py36,py37,pypy3,flake8'
 
 
@@ -128,21 +135,21 @@ def test_update_tox_envlist():
     (['2.7'], 'py27,pypy,flake8'),
 ])
 def test_update_tox_envlist_keeps_the_right_pypy(versions, expected):
-    result = update_tox_envlist('py27,py37,pypy,pypy3,flake8', versions)
+    result = update_tox_envlist('py27,py37,pypy,pypy3,flake8', v(versions))
     assert result == expected
 
 
 def test_update_tox_envlist_with_suffixes():
     result = update_tox_envlist(
         'py27,py34,py35,py36,py37,py27-numpy,py37-numpy,pypy,pypy3',
-        ['3.6', '3.7'])
+        v(['3.6', '3.7']))
     assert result == 'py36,py37,py37-numpy,pypy3'
 
 
 def test_update_tox_envlist_with_spaces():
     result = update_tox_envlist(
         'py27, py34, py35, pypy3',
-        ['3.6', '3.7'])
+        v(['3.6', '3.7']))
     assert result == 'py36, py37, pypy3'
 
 
@@ -155,7 +162,7 @@ def test_update_tox_envlist_with_spaces():
     ('\npy27,py34,py35,pypy3', 'py36,py37,pypy3'),
 ])
 def test_update_tox_envlist_with_newlines(s, expected):
-    result = update_tox_envlist(s, ['3.6', '3.7'])
+    result = update_tox_envlist(s, v(['3.6', '3.7']))
     assert result == expected
 
 
@@ -186,5 +193,5 @@ def test_update_tox_envlist_with_newlines(s, expected):
      'py{36,37}-nocrypto'),
 ])
 def test_update_tox_envlist_with_braces(s, expected):
-    result = update_tox_envlist(s, ['3.6', '3.7'])
+    result = update_tox_envlist(s, v(['3.6', '3.7']))
     assert result == expected
